@@ -11,7 +11,7 @@ class IODict(dict):
         # if first argument is data-string,
         # try to decode it using all decoders.
         if len(args) and isinstance(args[0], string_types):
-            d = IODict._from_any_data_string(args[0])
+            d = IODict._from_any_data_string(args[0], **kwargs)
             if d and isinstance(d, dict):
                 args = list(args)
                 args[0] = d
@@ -49,34 +49,25 @@ class IODict(dict):
 
     @staticmethod
     def _from_any_data_string(s, **kwargs):
-        try:
-            d = IODict.from_base64(s, **kwargs)
-            return d
-        except ValueError:
-            pass
-        try:
-            d = IODict.from_json(s, **kwargs)
-            return d
-        except ValueError:
-            pass
-        try:
-            d = IODict.from_toml(s, **kwargs)
-            return d
-        except ValueError:
-            pass
-        try:
-            d = IODict.from_xml(s, **kwargs)
-            return d
-        except ValueError:
-            pass
-        try:
-            d = IODict.from_yaml(s, **kwargs)
-            return d
-        except ValueError:
-            pass
+        funcs = [
+            IODict.from_base64,
+            IODict.from_json,
+            IODict.from_query_string,
+            IODict.from_toml,
+            IODict.from_xml,
+            IODict.from_yaml,
+        ]
+        for f in funcs:
+            try:
+                options = kwargs.copy()
+                d = f(s, **options)
+                return d
+            except ValueError:
+                pass
 
     @staticmethod
-    def from_base64(s, **kwargs):
+    def from_base64(s, format='json', **kwargs):
+        kwargs['format'] = format
         return IODict._decode(s,
             decoder=io_util.decode_base64, **kwargs)
 
@@ -105,12 +96,13 @@ class IODict(dict):
         return IODict._decode(s,
             decoder=io_util.decode_xml, **kwargs)
 
-    @classmethod
-    def from_yaml(cls, s, **kwargs):
+    @staticmethod
+    def from_yaml(s, **kwargs):
         return IODict._decode(s,
             decoder=io_util.decode_yaml, **kwargs)
 
-    def to_base64(self, filepath=None, **kwargs):
+    def to_base64(self, filepath=None, format='json', **kwargs):
+        kwargs['format'] = format
         return IODict._encode(self,
             encoder=io_util.encode_base64,
             filepath=filepath, **kwargs)
