@@ -5,11 +5,11 @@ from six import string_types
 
 def all_keys(d):
     keys = []
-    for key, val in d.items():
+    for key, value in d.items():
         if key not in keys:
             keys.append(key)
-        if isinstance(val, dict):
-            keys += all_keys(val)
+        if isinstance(value, dict):
+            keys += all_keys(value)
     return keys
 
 
@@ -23,6 +23,23 @@ def check_keys(keys, separator):
                 '\'{}\'.'.format(separator))
 
 
+def follow_keys(d, keys):
+    item_keys = keys[:-1]
+    item_key = keys[-1]
+    item_parent = d
+    i = 0
+    j = len(item_keys)
+    while i < j:
+        key = item_keys[i]
+        try:
+            item_parent = item_parent[key]
+        except KeyError:
+            item_parent = None
+            break
+        i += 1
+    return (item_parent, item_key, )
+
+
 def join_keys(keys, separator):
     return separator.join(keys)
 
